SPPackage class

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

SPPackage({String? artistName, String? download, String? language, String? newThing, String? packageAnimated, String? packageCategory, int packageId = -1, String? packageImg, String? packageKeywords, String? packageName, String? wish, String? view, int order = -1, List<SPSticker> stickers = const <SPSticker>[]})
SPPackage.fromJson(Map<String, dynamic> json)
factory

Properties

artistName → String?
final
download → String?
final
hashCode → int
The hash code for this object.
no setterinherited
isDownload → bool
no setter
isView → bool
no setter
language → String?
final
newThing → String?
final
order → int
final
packageAnimated → String?
final
packageCategory → String?
final
packageId → int
final
packageImg → String?
final
packageKeywords → String?
final
packageName → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stickers ↔ List<SPSticker>
getter/setter pair
view → String?
final
wish → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited