SPSticker class

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

SPSticker({int packageId = -1, int stickerId = -1, String? stickerImg, String? stickerImgLocalFilePath, String favoriteYN = "", String keyword = ""})
SPSticker.fromJson(Map<String, dynamic> json)
factory

Properties

favoriteYN → String
final
hashCode → int
The hash code for this object.
no setterinherited
keyword → String
final
packageId → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stickerId → int
final
stickerImg → String?
final
stickerImgLocalFilePath → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited